Learn R Programming

gek (version 1.2.0)

confint.gekm: Confint Method for a gekm Object

Description

Determines confidence intervals for the estimated regression coefficients.

Usage

# S3 method for gekm
confint(object, parm, level = 0.95, scale = FALSE, ...)

Value

A matrix with the lower and upper bounds of the confidence intervals for each parameter.

Arguments

object

an object of class "gekm".

parm

a vector of numbers or names specifying the parameters for which the confidence intervals are to be calculated. By default, all parameters are considered.

level

confidence level for calculating confidence intervals. Default is 0.95.

scale

logical. Should the estimated process variance be scaled? Default is FALSE, see sigma.gekm for details.

...

further arguments, currently not used.

Author

Carmen van Meegen

References

Koehler, J. and Owen, A. (1996). Computer Experiments. In Ghosh, S. and Rao, C. (eds.), Design and Analysis of Experiments, volume 13 of Handbook of Statistics, pp. 261–308. Elsevier Science. tools:::Rd_expr_doi("10.1016/S0169-7161(96)13011-X").

Santner, T. J., Williams, B. J., and Notz, W. I. (2018). The Design and Analysis of Computer Experiments. 2nd edition. Springer-Verlag.

See Also

gekm for fitting a (gradient-enhanced) Kriging model.

coef for extracting the (matrix of) coefficients.

vcov for calculating the covaraince matrix of the regression coefficients.

Examples

Run this code
## 1-dimensional example: Oakley and O’Hagan (2002)

# Define test function and its gradient 
f <- function(x) 5 + x + cos(x)
fGrad <- function(x) 1 - sin(x)

# Generate coordinates and calculate slopes
x <- seq(-5, 5, length = 5)
y <- f(x)
dy <- fGrad(x)
dat <- data.frame(x, y)
deri <- data.frame(x = dy)

# Fit gradient-enhanced Kriging model
gekm.1d <- gekm(y ~ ., data = dat, deriv = deri, covtype = "gaussian", theta = 1)

# Determine confidence intervals
confint(gekm.1d)
confint(gekm.1d, scale = TRUE)
confint(gekm.1d, parm = "x", scale = TRUE)
confint(gekm.1d, parm = 1, scale = TRUE)

Run the code above in your browser using DataLab