The steel column function is defined by $$f_{\rm steel}(x) = F_S - P \left(\frac{1}{2BD} + \frac{F_0 E_b}{BDH(E_b - P)} \right),$$ with \(P = P_1 + P_2 + P_3\), \(E_b = \frac{\pi^2 EBDH^2}{2L^2}\) and \(x = (F_S, P_1, P_2, P_3, B, D, H, F_0, E)\).
steel(x, L = 7500)
steelGrad(x, L = 7500)steel returns the function value of steel column function at x.
steelGrad returns the gradient of steel column function at x.
Carmen van Meegen
The steel column function describes the limite state function of a steel column with uncertain parameters.
| Input | Distribution | Mean | Standard Deviation | Description | \(F_S\) |
| \(\mathcal{LN}\) | \(400\) | \(35\) | yield stress in \(\rm MPa\) | \(P_1\) | \(\mathcal{N}\) |
| \(500000\) | \(50000\) | dead weight load in \(\rm N\) | \(P_2\) | \(\mathcal{G}\) | \(600000\) |
| \(90000\) | variable load in \(\rm N\) | \(P_3\) | \(\mathcal{G}\) | \(600000\) | \(90000\) |
| variable load in \(\rm N\) | \(B\) | \(\mathcal{LN}\) | \(b\) | \(3\) | flange breadth in \(\rm mm\) |
| \(D\) | \(\mathcal{LN}\) | \(t\) | \(2\) | flange thickness in \(\rm mm\) | \(H\) |
| \(\mathcal{LN}\) | \(h\) | \(5\) | profile height in \(\rm mm\) | \(F_0\) | \(\mathcal{N}\) |
| \(30\) | \(10\) | initial deflection in \(\rm mm\) | \(E\) | \(\mathcal{W}\) | \(210000\) |
Here, \(\mathcal{N}\) is the normal distribution and \(\mathcal{LN}\) is the log-normal distribution. Further, \(\mathcal{G}\) represents the Gumbel distribution and \(\mathcal{W}\) denotes the Weibull distribution.
Kuschel, N. and Rackwitz, R. (1997). Two Basic Problems in Reliability-Based Structural Optimization. Mathematical Methods of Operations Research, 46(3):309--333.
Surjanovic, S. and Bingham, D. (2013). Virtual Library of Simulation Experiments: Test Functions and Datasets. https://www.sfu.ca/~ssurjano/ (retrieved January 19, 2024).
testfunctions for further test functions.